"""
Module which takes a string of house numbers and turns them into series.
"""

import collections

from housenumparser.element import BisLetter
from housenumparser.element import BisLetterSequence
from housenumparser.element import BisNumber
from housenumparser.element import BisNumberSequence
from housenumparser.element import BusLetter
from housenumparser.element import BusLetterSequence
from housenumparser.element import BusNumber
from housenumparser.element import BusNumberSequence
from housenumparser.element import HouseNumber
from housenumparser.element import HouseNumberSequence
from housenumparser.element import ReadException


def group(data):
    """
    Groups all `SingleElement` objects by their type.

    :type data: list[.element.SingleElement]
    :param data: Supported types in the list: HouseNumber, BisNumber,
       BisLetter, BusNumber, BusLetter.

    :results: A dictionary containing lists of :class:`.element.SingleElement`.
    """
    result = {
        'house_numbers': [],
        'bis_numbers': [],
        'bis_letters': [],
        'bus_numbers': [],
        'bus_letters': [],
        'bad_data': [],
    }
    for x in data:
        if isinstance(x, HouseNumber):
            result['house_numbers'].append(x)
        elif isinstance(x, BisNumber):
            result['bis_numbers'].append(x)
        elif isinstance(x, BisLetter):
            result['bis_letters'].append(x)
        elif isinstance(x, BusNumber):
            result['bus_numbers'].append(x)
        elif isinstance(x, BusLetter):
            result['bus_letters'].append(x)
        elif isinstance(x, ReadException):
            result['bad_data'].append(x)
    return result


def merge_data(data, on_exc=ReadException.Action.ERROR_MSG):
    """
    Merges single elements into sequences where possible.

    :type data: dict[str, list[.element.SingleElement]]
    :param data: data as returned by the `group` function

    :type on_exc: :class:`.element.ReadException.Action`
    :param on_exc: Flag on how to treat incorrect data. Default ERROR_MSG.

    :returns: A list of :class:`.element.SingleElement` and if possible
       :class:`.element.SequenceElement`.
    """
    merged_data = []
    merged_data.extend(
        merge_numbers([obj.house_number for obj in data['house_numbers']],
                      lambda num: HouseNumber(num),
                      lambda first, last: HouseNumberSequence(first, last),
                      (1, 2))
    )
    # For anything else below here, we must first "group by" the data
    # per house number
    numbers_per_house = collections.defaultdict(list)
    original_strings = {}
    for element in data['bis_numbers']:
        numbers_per_house[element.house_number].append(element.bis_number)
        original_strings[element.house_number] = element.original_string

    for house_number, numbers in numbers_per_house.items():
        merged_data.extend(
            merge_numbers(
                numbers, lambda num: BisNumber(
                    house_number, num, original_strings[house_number]
                ),
                lambda first, last: BisNumberSequence(
                    house_number, first, last, original_strings[house_number]
                ),
                (1,))
        )
    numbers_per_house = collections.defaultdict(list)
    for element in data['bus_numbers']:
        numbers_per_house[element.house_number].append(element.bus_number)
    for house_number, numbers in numbers_per_house.items():
        merged_data.extend(
            merge_numbers(
                numbers, lambda num: BusNumber(house_number, num),
                lambda first, last: BusNumberSequence(house_number, first,
                                                      last),
                (1,))
        )
    # Treat letters the same as numbers, use `ord` and `chr` to turn the
    # letters into numbers and back into letters.
    letters_per_house = collections.defaultdict(list)
    for element in data['bis_letters']:
        letters_per_house[element.house_number].append(ord(element.bis_letter))
    for house_number, numbers in letters_per_house.items():
        merged_data.extend(
            merge_numbers(
                numbers, lambda num: BisLetter(house_number, chr(num)),
                lambda first, last: BisLetterSequence(house_number, chr(first),
                                                      chr(last)),
                (1,))
        )
    letters_per_house = collections.defaultdict(list)
    for element in data['bus_letters']:
        letters_per_house[element.house_number].append(ord(element.bus_letter))
    for house_number, numbers in letters_per_house.items():
        merged_data.extend(
            merge_numbers(
                numbers, lambda num: BusLetter(house_number, chr(num)),
                lambda first, last: BusLetterSequence(house_number, chr(first),
                                                      chr(last)),
                (1,))
        )
    # raise wouldn't have reached this point, drop needs no action.
    if on_exc in (ReadException.Action.ERROR_MSG,
                  ReadException.Action.KEEP_ORIGINAL):
        merged_data.extend(data['bad_data'])
    return merged_data


def merge_numbers(data, single_result, sequence_result, allowed_steps):
    """
    Takes a list of integers and merges them into sequences.

    The list of ints (data) will be traversed and whenever it finds a single
    value, it will call `single_result` and add the result to a new list.
    For every sequence it finds by traversing over the data, it will call
    `sequence_result` and add that to the new list. When the data is
    traversed entirely, the new list returns.

    To determine whether it's a sequence or not, the next number is previewed
    while traversing, and if the difference between the current number and the
    next number is one of the `allowed_steps` it's a sequence.

    :type data: list[int]
    :param data: numbers in which to find sequences.

    :type single_result: Callable[int]
    :param single_result: function which takes 1 parameter. Should return a
       SingleElement instance.

    :type sequence_result: Callable[int, int]
    :param sequence_result: function which takes 2 parameter: first, last.
       Should return a SequenceElement instance.

    :type allowed_steps: tuple
    :param allowed_steps: steps allowed between 2 elements to be in a sequence

    :returns: List of :class:`.element.Element`, using Sequences if possible.
    """
    data = list(set(data))
    data.sort()
    total_len = len(data)
    data = data + [-1, -1]
    result = []

    start = end = step = None
    index = 0
    while index < total_len:
        first = data[index]
        second = data[index + 1]
        index += 1

        # If no current sequence going on: Start new sequence or single number
        if step is None:
            step = second - first
            if step not in allowed_steps:
                # Add a single house number, no sequence possible
                result.append(single_result(first))
                step = None
                continue
            else:
                # Start a new sequence, store the starting number.
                start = first
        # The next number is still valid for the current sequence.
        if second - first == step:
            end = second
        else:  # This marks the end of the sequence.
            if step == 1 and 2 in allowed_steps and (end - start) % 2 == 0:
                # If 2 steps are allowed, 1-5 is actually 1,3,5 and not
                # 1,2,3,4,5 - So we create 1-4, and treat the 5 as new.
                end = end - step
                index -= 1
            result.append(sequence_result(start, end))
            step = None
    return result



import logging

from housenumparser import merger
from housenumparser import reader
from housenumparser.element import ReadException

LOG = logging.getLogger(__name__)


def split(data, step=None, on_exc=ReadException.Action.ERROR_MSG):
    """
    Parses a string of house number series and returns single numbers.

    :type data: Union[str, list[str]]
    :param data: house number and/or house number series representations

    :type step: int
    :param step: Amount of house numbers per step. Commonly 1 or 2.
       Default None.
       When `None`, it will use 2 if beginning and ending of a
       series are both even or uneven, 1 otherwise.

    :type on_exc: :class:`.element.ReadException.Action`
    :param on_exc: Flag on how to treat incorrect data. Default ERROR_MSG.

    :returns: A list of :class:`.element.SingleElement`
    """
    try:
        if isinstance(data, list):
            numbers = reader.read_iterable(data, step=step, on_exc=on_exc)
        else:
            numbers = reader.read_data(data, step=step, on_exc=on_exc)
        return [item for number in numbers for item in number.split()]
    except Exception:  # noqa
        LOG.error(f"Could not split data: {data}")
        raise


def merge(data, on_exc=ReadException.Action.ERROR_MSG):
    """
    Parses a string or list of house number series and returns elements merged
    into sequences if possible.

    :type data: Union[str, list[str]]
    :param data: house number and/or house number series representations

    :type on_exc: :class:`.element.ReadException.Action`
    :param on_exc: Flag on how to treat incorrect data. Default ERROR_MSG.

    :returns: A list of :class:`.element.Element`
    """
    try:
        numbers = split(data, on_exc=on_exc)
        return merger.merge_data(merger.group(numbers))
    except Exception:  # noqa
        LOG.error(f"Could not merge data: {data}")
        raise



import re
from enum import Enum


class Element:
    """
    A house number element.

    This is an abstract superclass for all output of the housenumparser.reader
    This can be a house number, a house number series, readingerror, etc.
    """

    def __init__(self, first_house_number, first_bis_number=-1,
                 first_bis_letter=-1, first_bus_number=-1, first_bus_letter=-1,
                 last_house_number=-1, last_bis_number=-1, last_bis_letter=-1,
                 last_bus_number=-1, last_bus_letter=-1):
        """
        :type first_house_number: int
        :param first_house_number: First house_number.

        :type first_bis_number: int
        :param first_bis_number: First bis number.

        :type first_bis_letter: str
        :param first_bis_letter: First bis letter.

        :type first_bus_number: int
        :param first_bus_number: First bus number.

        :type first_bus_letter: str
        :param first_bus_letter: First bus letter.

        :type last_house_number: int
        :param last_house_number: Last house_number of the series.

        :type last_bis_number: int
        :param last_bis_number: Last bis number of the series.

        :type last_bis_letter: str
        :param last_bis_letter: Last bis letter of the series.

        :type last_bus_number: int
        :param last_bus_number: Last bus number of the series.

        :type last_bus_letter: str
        :param last_bus_letter: Last bus letter of the series.
        """
        self.first_house_number = first_house_number
        self.first_bis_number = first_bis_number
        self.first_bis_letter = first_bis_letter
        self.first_bus_number = first_bus_number
        self.first_bus_letter = first_bus_letter
        self.last_house_number = last_house_number
        self.last_bis_number = last_bis_number
        self.last_bis_letter = last_bis_letter
        self.last_bus_number = last_bus_number
        self.last_bus_letter = last_bus_letter

    @property
    def house_number(self):
        """
        :returns: The house number attribute of the object.
        """
        return self.first_house_number


class ReadException(Element):
    """
    Class for a reading error in housenumparser.reader.
    """

    class Action(Enum):
        """
        Enum of possible actions to take when encountering bad input.
        """
        RAISE = 1  # Raises exception on bad input
        ERROR_MSG = 2  # An error message will return
        KEEP_ORIGINAL = 3  # The original data will return
        DROP = 4  # The error will be ignored, and not exist in the output.

    def __init__(self, error, data="", on_exc=Action.ERROR_MSG):
        super().__init__(-1)
        self.error = error
        self.data = data
        self.on_exc = on_exc

    def split(self):
        return [self]

    def __str__(self):
        if self.on_exc == ReadException.Action.KEEP_ORIGINAL:
            return self.data
        if self.on_exc == ReadException.Action.ERROR_MSG:
            return f'{self.error}: {self.data}'
        return '<ReadException> Not implemented on_exc: ' + str(self.on_exc)


class SequenceElement(Element):
    """
    Abstract class of all series of house numbers.
    """


class HouseNumberSequence(SequenceElement):
    """
    A series of house numbers. eg:

    - "33, 35, 37" -> "33-37"
    - "33, 34, 35, 36" -> "33-36"
    - "32, 33, 34, 35, 36"-> "32, 33-36"
    """
    regex = re.compile(r'^(\d+)-(\d+)$')

    def __init__(self, first_house_number, last_house_number, step=None):
        """
        :type first_house_number: int
        :param first_house_number: First house number of the series.

        :type last_house_number: int
        :param last_house_number: Last house number of the series.

        :type step: int
        :param step: Step to take between first and last element.
        """
        self.step = step or self._default_step(first_house_number,
                                               last_house_number)
        super().__init__(
            first_house_number, last_house_number=last_house_number
        )
        if self.first_house_number > self.last_house_number:
            raise ValueError('Incorrect range')

    def _default_step(self, first, last):
        """
        Calculates the step based on the first and last number

        :type first: int
        :param first: First number of the series

        :type first: int
        :param last: Last number of the series

        :return: 2 if both numbers are even or uneven. 1 if they're different.
        """
        return 2 if first % 2 == last % 2 else 1

    def __str__(self):
        return ('{first_house}-{last_house}'
                .format(first_house=self.first_house_number,
                        last_house=self.last_house_number))

    def split(self):
        """
         :returns: A list of :class:`HouseNumber`
        """
        return [HouseNumber(number) for number
                in range(self.first_house_number, self.last_house_number + 1,
                         self.step)]


class BisNumberSequence(SequenceElement):
    """
    A series of bis numbers.

    eg: "33/1, 32/2, 33/3" -> "33/1-3"
    """
    regex = re.compile(r'^(\d+)[/_](\d+)-(\d+)$')

    def __init__(self, house_number, first_bis_number, last_bis_number, original_string):
        """
        :type house_number: int
        :param house_number: House number.

        :type house_number: int
        :param first_bis_number: First bis number of the series.

        :type house_number: int
        :param last_bis_number: Last bis number of the series

        :type original_string: str
        :param original_string: Original string
        """
        super().__init__(
            house_number, first_bis_number=first_bis_number,
            last_bis_number=last_bis_number
        )
        self.original_string = original_string
        if self.first_bis_number > self.last_bis_number:
            raise ValueError('Incorrect range')

    def __str__(self):
        if '_' in self.original_string:
            return ('{house_number}_{first_bis}-{last_bis}'
                    .format(house_number=self.house_number,
                            first_bis=self.first_bis_number,
                            last_bis=self.last_bis_number))
        else:
            return ('{house_number}/{first_bis}-{last_bis}'
                    .format(house_number=self.house_number,
                            first_bis=self.first_bis_number,
                            last_bis=self.last_bis_number))

    def split(self):
        """
        :returns: A list of :class:`BisNumber`
        """
        return [
            BisNumber(self.house_number, bis_number, self.original_string)
            for bis_number in range(self.first_bis_number, self.last_bis_number + 1)
        ]


class BisLetterSequence(SequenceElement):
    """
    A series of bis letters.
    """
    regex = re.compile(r'^(\d+)/?([a-zA-Z]+)-([a-zA-Z]+)$')

    def __init__(self, house_number, first_bis_letter, last_bis_letter):
        """
        :type house_number: int
        :param house_number: House number

        :type first_bis_letter: str
        :param first_bis_letter: First letter of the series.

        :type last_bis_letter: str
        :param last_bis_letter: Last letter of the series.
        """
        super().__init__(
            house_number, first_bis_letter=first_bis_letter,
            last_bis_letter=last_bis_letter
        )
        start = ord(self.first_bis_letter)
        end = ord(self.last_bis_letter)
        if start > end:
            raise ValueError('Incorrect range')

    def __str__(self):
        return ('{house_number}{first_letter}-{last_letter}'
                .format(house_number=self.house_number,
                        first_letter=self.first_bis_letter,
                        last_letter=self.last_bis_letter))

    def split(self):
        """
        :returns: A list of :class:`BisLetter`
        """
        start = ord(self.first_bis_letter)
        end = ord(self.last_bis_letter)
        return [BisLetter(self.house_number, chr(i)) for i
                in range(start, end + 1)]


class BusNumberSequence(SequenceElement):
    """
    A series of bus numbers.

    eg: "33 bus 1, 32 bus 2, 33 bus 3" -> "33 bus 1-3"
    """
    regex = re.compile(r'^(\d+)bus(\d+)-(\d+)$')

    def __init__(self, house_number, first_bus_number, last_bus_number):
        """
        :type house_number: int
        :param house_number: House number.

        :type first_bus_number: int
        :param first_bus_number: First number of the series.

        :type last_bus_number: int
        :param last_bus_number: Last number of the series.
        """
        super().__init__(
            house_number, first_bus_number=first_bus_number,
            last_bus_number=last_bus_number
        )
        if self.first_bus_number > self.last_bus_number:
            raise ValueError('Incorrect range')

    def __str__(self):
        return ('{house_number} bus {first_bus}-{last_bus}'
                .format(house_number=self.house_number,
                        first_bus=self.first_bus_number,
                        last_bus=self.last_bus_number))

    def split(self):
        """
        :returns: A list of :class:`BusNumber`
        """
        return [BusNumber(self.house_number, bus_number) for bus_number
                in range(self.first_bus_number, self.last_bus_number + 1)]


class BusLetterSequence(SequenceElement):
    """
    A series of busletters.

    eg: "33 bus A, 32 bus B, 33 bus C" -> "33 bus A-C"
    """
    regex = re.compile(r'^(\d+)bus([a-zA-Z]+)-([a-zA-Z]+)$')

    def __init__(self, house_number, first_bus_letter, last_bus_letter):
        """
        :type house_number: int
        :param house_number: House number

        :type first_bus_letter: str
        :param first_bus_letter: First letter of the series.

        :type last_bus_letter: str
        :param last_bus_letter: Last letter of the series.
        """
        super().__init__(
            house_number, first_bus_letter=first_bus_letter,
            last_bus_letter=last_bus_letter
        )
        start = ord(self.first_bus_letter)
        end = ord(self.last_bus_letter)
        if start > end:
            raise ValueError('Incorrect range')

    def __str__(self):
        return ('{house_number} bus {first_letter}-{last_letter}'
                .format(house_number=self.house_number,
                        first_letter=self.first_bus_letter,
                        last_letter=self.last_bus_letter))

    def split(self):
        """
        :returns: A list of :class:`BusLetter`
        """
        return [BusLetter(self.house_number, chr(i)) for i
                in range(ord(self.first_bus_letter),
                         ord(self.last_bus_letter) + 1)]


class SingleElement(Element):
    """
    An abstract superclass for house numbers.
    """

    def split(self):
        return [self]


class HouseNumber(SingleElement):
    """
    A simple house number. eg: 13 or 15.
    """
    sequence_class = HouseNumberSequence
    regex = re.compile(r'^(\d+)$')

    def __str__(self):
        return str(self.house_number)


class BisNumber(SingleElement):
    """
    A house number with bis number.

    eg: "3/1" or "21/5"
    """
    sequence_class = BisNumberSequence
    regex = re.compile(r'^(\d+)[/_](\d+)$')

    def __init__(self, house_number, bis_number, original_string):
        """
        :type house_number: int
        :param house_number: House number

        :type bis_number: int
        :param bis_number: Bis number

        :type original_string: str
        :param bis_number: Original string
        """
        super().__init__(
            house_number,
            first_bis_number=bis_number,
        )
        self.original_string = original_string

    @property
    def bis_number(self):
        return self.first_bis_number

    def __str__(self):
        if '_' in self.original_string:
            return '{house}_{bis_number}'.format(house=self.house_number,
                                                 bis_number=self.bis_number)
        else:
            return '{house}/{bis_number}'.format(house=self.house_number,
                                                 bis_number=self.bis_number)


class BusNumber(SingleElement):
    """
    A house number with bus number.

    eg: "3 bus 1" or "53 bus 5"
    """
    sequence_class = BusNumberSequence
    regex = re.compile(r'^(\d+)bus(\d+)$')

    def __init__(self, house_number, bus_number):
        """
        :type house_number: int
        :param house_number: House number

        :type bus_number: int
        :param bus_number: Bus number
        """
        super().__init__(house_number, first_bus_number=bus_number)

    @property
    def bus_number(self):
        return self.first_bus_number

    def __str__(self):
        return '{house} bus {bus_number}'.format(house=self.house_number,
                                                 bus_number=self.bus_number)


class BusLetter(SingleElement):
    """
    A house number with bus letter.

    eg: "3 bus A" or "53 bus D"
    """
    sequence_class = BusLetterSequence
    regex = re.compile(r'^(\d+)bus([a-zA-Z])$')

    def __init__(self, house_number, bus_letter):
        """
        :type house_number: int
        :param house_number: House number

        :type bus_letter: str
        :param bus_letter: Bus letter
        """
        super().__init__(house_number, first_bus_letter=bus_letter)

    @property
    def bus_letter(self):
        return self.first_bus_letter

    def __str__(self):
        return '{house} bus {bus_letter}'.format(house=self.house_number,
                                                 bus_letter=self.bus_letter)


class BisLetter(SingleElement):
    """
    A house number with bis letter.

    eg: "3A" or "53D"
    """
    sequence_class = BisLetterSequence
    regex = re.compile(r'^(\d+)[/_]?([a-zA-Z])$')

    def __init__(self, house_number, bis_letter):
        """
        :type house_number: int
        :param house_number: House number

        :type bis_letter: str
        :param bis_letter: Bis letter
        """
        super().__init__(house_number, first_bis_letter=bis_letter)

    @property
    def bis_letter(self):
        return self.first_bis_letter

    def __str__(self):
        return '{house}{bis_letter}'.format(house=self.house_number,
                                            bis_letter=self.bis_letter)



"""
Module which reads string data into :class:`housenumparser.element.Element`
elements.

eg:
- "23 bus 5, 23 bus 6" -> [<BusNumber> "23 bus 5", <BusNumber> "23 B-6"]
- "23", "24 bus 2" -> [<HouseNumber> "23", <BusNumber> "24 bus 2"]
- "25-27" -> [<HouseNumberSequence> "25-26", <HouseNumber> "27"]
"""

import re

from housenumparser.element import BisLetter
from housenumparser.element import BisLetterSequence
from housenumparser.element import BisNumber
from housenumparser.element import BisNumberSequence
from housenumparser.element import BusLetter
from housenumparser.element import BusLetterSequence
from housenumparser.element import BusNumber
from housenumparser.element import BusNumberSequence
from housenumparser.element import HouseNumber
from housenumparser.element import HouseNumberSequence
from housenumparser.element import ReadException


def read_data(data, step=None, on_exc=ReadException.Action.ERROR_MSG):
    """
    Parses a comma-seperated string of house number elements.

    :type data: str
    :param data: A :class:`str` with comma-seperated house numbers

    :type step: int
    :param step: Amount of house numbers per step. Commonly 1 or 2.
       Default None.
       When `None`, it will use 2 if beginning and ending of a
       series are both even or uneven, 1 otherwise.

    :type on_exc: .element.ReadException.Action
    :param on_exc: Flag on how to treat incorrect data. Default ERROR_MSG.

    :returns: A list from of the data.
    """
    return read_iterable(str(data).split(","), step=step,
                         on_exc=on_exc)


def read_iterable(inputs, step=None, on_exc=ReadException.Action.ERROR_MSG):
    """
    Parses an iterable of house number element strings.

    :type inputs: list[str]
    :param inputs: A list of house numbers and/or house number series.

    :type step: int
    :param step: Amount of house numbers per step. Commonly 1 or 2.
       Default None.
       When `None`, it will use 2 if beginning and ending of a series are
       both even or uneven, 1 otherwise.

    :type on_exc: .element.ReadException.Action
    :param on_exc: Flag on how to treat incorrect data. Default ERROR_MSG.

    :returns: A list of :class:`.element.Element`.
    """
    result = []
    for data in inputs:
        data = data.strip() if data else str(data)
        parsed_element = read_element(data, step=step, on_exc=on_exc)
        if parsed_element is not None:
            result.append(parsed_element)
    return result


def read_element(data, step=None, on_exc=ReadException.Action.ERROR_MSG):
    """
    Parses a single house number element string.

    :type data: str
    :param data: A String representating a house number.

    :type step: int
    :param step: Amount of house numbers per step. Commonly 1 or 2.
       Default None.
       When `None`, it will use 2 if beginning and ending of a
       series are both even or uneven, 1 otherwise.

    :type on_exc: ReadException.Action
    :param on_exc: Flag on how to treat incorrect data. Default ERROR_MSG.

    :returns: A :class:`.element.Element` OR an exception in case of
       incorrect data.
    """
    element_classes = [BusNumberSequence, BusLetterSequence, BisNumberSequence,
                       BisLetterSequence, BusNumber, BusLetter, BisNumber,
                       BisLetter, HouseNumberSequence, HouseNumber]
    stripped_data = re.sub(r'\s', '', data)
    exception = None
    try:
        for element_class in element_classes:
            match = element_class.regex.match(stripped_data)
            if match:
                args = [int(group) if group.isdigit() else group
                        for group in match.groups()]
                kwargs = {}
                if element_class == HouseNumberSequence:
                    kwargs['step'] = step
                if element_class in [BisNumber, BisNumberSequence]:
                    kwargs['original_string'] = stripped_data
                return element_class(*args, **kwargs)
    except ValueError as e:
        exception = e
    if on_exc == ReadException.Action.RAISE:
        if exception:
            msg = str(exception)
        else:
            msg = "Could not parse/understand"
        raise ValueError(msg + ': ' + data)
    elif on_exc == ReadException.Action.DROP:
        return None
    elif on_exc in (ReadException.Action.ERROR_MSG,
                    ReadException.Action.KEEP_ORIGINAL):
        if exception:
            msg = str(exception)
        else:
            msg = "Could not parse/understand"
        return ReadException(msg, data=data, on_exc=on_exc)
    raise ValueError("Not implemented on_exc: " + str(on_exc))



#!/usr/bin/env python

import os

from setuptools import find_packages
from setuptools import setup

here = os.path.abspath(os.path.dirname(__file__))
README = open(os.path.join(here, 'README.rst')).read()


requires = [
    'enum34;python_version < "3.4"'
]

setup(
    name='housenumparser',
    version='0.2.0',
    description='housenum_be_r_parser',
    long_description=README,
    author='Onroerend Erfgoed',
    author_email='ict@onroerenderfgoed.be',
    url='http://github.com/onroerenderfgoed/housenum-be-r-parser',
    packages=find_packages(),
    package_data={'': ['LICENSE']},
    package_dir={'housenumparser': 'housenumparser'},
    include_package_data=True,
    install_requires=requires,
    license='MIT',
    zip_safe=False,
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    test_suite='tox'
)
